@@ -40,6 +40,7 @@ class LoggingConfigForm extends Form
                 'description'   => $this->translate('The type of logging to utilize.'),
                 'multiOptions'  => array(
                     'syslog'    => 'Syslog',
+                    'php'       => $this->translate('Webserver Log', 'app.config.logging.type'),
                     'file'      => $this->translate('File', 'app.config.logging.type'),
                     'none'      => $this->translate('None', 'app.config.logging.type')
                 )
@@ -64,7 +65,7 @@ class LoggingConfigForm extends Form
             );
         }
 
-        if (false === isset($formData['logging_log']) || $formData['logging_log'] === 'syslog') {
+        if (! isset($formData['logging_log']) || in_array($formData['logging_log'], array('syslog', 'php'))) {
             $this->addElement(
                 'text',
                 'logging_application',
@@ -72,7 +73,7 @@ class LoggingConfigForm extends Form
                     'required'      => true,
                     'label'         => $this->translate('Application Prefix'),
                     'description'   => $this->translate(
-                        'The name of the application by which to prefix syslog messages.'
+                        'The name of the application by which to prefix log messages.'
                     ),
                     'requirement'   => $this->translate('The application prefix must not contain whitespace.'),
                     'value'         => 'icingaweb2',
