@@ -4,9 +4,10 @@
 namespace Icinga\Forms;
 
 use Exception;
-use Icinga\Exception\ConfigurationError;
 use Zend_Form_Decorator_Abstract;
 use Icinga\Application\Config;
+use Icinga\Application\Hook\ConfigFormEventsHook;
+use Icinga\Exception\ConfigurationError;
 use Icinga\Web\Form;
 use Icinga\Web\Notification;
 
@@ -52,9 +53,21 @@ class ConfigForm extends Form
         return $this;
     }
 
-    /**
-     * {@inheritdoc}
-     */
+    public function isValid($formData)
+    {
+        $valid = parent::isValid($formData);
+
+        if ($valid && ConfigFormEventsHook::runIsValid($this) === false) {
+            foreach (ConfigFormEventsHook::getLastErrors() as $msg) {
+                $this->error($msg);
+            }
+
+            $valid = false;
+        }
+
+        return $valid;
+    }
+
     public function onSuccess()
     {
         $sections = array();
@@ -72,11 +85,15 @@ class ConfigForm extends Form
         } else {
             return false;
         }
+
+        if (ConfigFormEventsHook::runOnSuccess($this) === false) {
+            Notification::error($this->translate(
+                'Configuration successfully stored. Though, one or more module hooks failed to run.'
+                . ' See logs for details'
+            ));
+        }
     }
 
-    /**
-     * {@inheritdoc}
-     */
     public function onRequest()
     {
         $values = array();
