@@ -3,15 +3,17 @@
 
 namespace Icinga\Application;
 
+use DirectoryIterator;
 use ErrorException;
 use Exception;
+use ipl\I18n\GettextTranslator;
+use ipl\I18n\StaticTranslator;
 use LogicException;
 use Icinga\Application\Modules\Manager as ModuleManager;
 use Icinga\Authentication\User\UserBackend;
 use Icinga\Data\ConfigObject;
 use Icinga\Exception\ConfigurationError;
 use Icinga\Exception\NotReadableError;
-use Icinga\Util\Translator;
 use Icinga\Exception\IcingaException;
 
 /**
@@ -62,7 +64,7 @@ abstract class ApplicationBootstrap
     protected $vendorDir;
 
     /**
-     * Library directory
+     * Icinga library directory
      *
      * @var string
      */
@@ -89,6 +91,20 @@ abstract class ApplicationBootstrap
      */
     protected $storageDir;
 
+    /**
+     * External library paths
+     *
+     * @var string[]
+     */
+    protected $libraryPaths;
+
+    /**
+     * Loaded external libraries
+     *
+     * @var Libraries
+     */
+    protected $libraries;
+
     /**
      * Icinga class loader
      *
@@ -176,6 +192,20 @@ abstract class ApplicationBootstrap
         $canonical = realpath($storageDir);
         $this->storageDir = $canonical ? $canonical : $storageDir;
 
+        if ($this->libraryPaths === null) {
+            $libraryPaths = getenv('ICINGAWEB_LIBDIR');
+            if ($libraryPaths !== false) {
+                $this->libraryPaths = array_filter(array_map(
+                    'realpath',
+                    explode(':', $libraryPaths)
+                ), 'is_dir');
+            } else {
+                $this->libraryPaths = is_dir('/usr/share/icinga-php')
+                    ? ['/usr/share/icinga-php']
+                    : [];
+            }
+        }
+
         set_include_path(
             implode(
                 PATH_SEPARATOR,
@@ -197,6 +227,16 @@ abstract class ApplicationBootstrap
      */
     abstract protected function bootstrap();
 
+    /**
+     * Get loaded external libraries
+     *
+     * @return Libraries
+     */
+    public function getLibraries()
+    {
+        return $this->libraries;
+    }
+
     /**
      * Getter for module manager
      *
@@ -499,6 +539,26 @@ abstract class ApplicationBootstrap
         return @file_exists($this->config->resolvePath('setup.token'));
     }
 
+    /**
+     * Load external libraries
+     *
+     * @return $this
+     */
+    protected function loadLibraries()
+    {
+        $this->libraries = new Libraries();
+        foreach ($this->libraryPaths as $libraryPath) {
+            foreach (new DirectoryIterator($libraryPath) as $path) {
+                if (! $path->isDot() && is_dir($path->getRealPath())) {
+                    $this->libraries->registerPath($path->getPathname())
+                        ->registerAutoloader();
+                }
+            }
+        }
+
+        return $this;
+    }
+
     /**
      * Setup default logging
      *
@@ -546,7 +606,7 @@ abstract class ApplicationBootstrap
         ini_set('display_startup_errors', 1);
         ini_set('display_errors', 1);
         set_error_handler(function ($errno, $errstr, $errfile, $errline) {
-            if (error_reporting() === 0) {
+            if (! (error_reporting() & $errno)) {
                 // Error was suppressed with the @-operator
                 return false; // Continue with the normal error handler
             }
@@ -640,6 +700,19 @@ abstract class ApplicationBootstrap
         return null;
     }
 
+    /**
+     * Prepare internationalization using gettext
+     *
+     * @return $this
+     */
+    protected function prepareInternationalization()
+    {
+        StaticTranslator::$instance = (new GettextTranslator())
+            ->setDefaultDomain('icinga');
+
+        return $this;
+    }
+
     /**
      * Set up internationalization using gettext
      *
@@ -647,17 +720,20 @@ abstract class ApplicationBootstrap
      */
     final protected function setupInternationalization()
     {
+        /** @var GettextTranslator $translator */
+        $translator = StaticTranslator::$instance;
+
         if ($this->hasLocales()) {
-            Translator::registerDomain(Translator::DEFAULT_DOMAIN, $this->getLocaleDir());
+            $translator->addTranslationDirectory($this->getLocaleDir(), 'icinga');
         }
 
         $locale = $this->detectLocale();
         if ($locale === null) {
-            $locale = Translator::DEFAULT_LOCALE;
+            $locale = $translator->getDefaultLocale();
         }
 
         try {
-            Translator::setupLocale($locale);
+            $translator->setLocale($locale);
         } catch (Exception $error) {
             Logger::error($error);
         }
@@ -694,27 +770,15 @@ abstract class ApplicationBootstrap
     /**
      * List all available locales
      *
-     * NOTE: Might be a candidate for a static function in Translator
+     * @return array Locale list
      *
-     * return array Locale list
+     * @deprecated Use {@see \ipl\I18n\GettextTranslator::listLocales()} instead
      */
     public function listLocales()
     {
-        $locales = array();
-        if (! $this->hasLocales()) {
-            return $locales;
-        }
-        $localedir = $this->getLocaleDir();
+        /** @var GettextTranslator $translator */
+        $translator = StaticTranslator::$instance;
 
-        $dh = opendir($localedir);
-        while (false !== ($file = readdir($dh))) {
-            $filename = $localedir . DIRECTORY_SEPARATOR . $file;
-            if (preg_match('/^[a-z]{2}_[A-Z]{2}$/', $file) && is_dir($filename)) {
-                $locales[] = $file;
-            }
-        }
-        closedir($dh);
-        sort($locales);
-        return $locales;
+        return $translator->listLocales();
     }
 }
