@@ -38,8 +38,10 @@ class Cli extends ApplicationBootstrap
         $this->assertRunningOnCli();
         $this->setupLogging()
             ->setupErrorHandling()
+            ->loadLibraries()
             ->loadConfig()
             ->setupTimezone()
+            ->prepareInternationalization()
             ->setupInternationalization()
             ->parseBasicParams()
             ->setupLogger()
