@@ -5,6 +5,10 @@ namespace Icinga\Application;
 
 require_once __DIR__ . '/EmbeddedWeb.php';
 
+use ErrorException;
+use ipl\I18n\GettextTranslator;
+use ipl\I18n\Locale;
+use ipl\I18n\StaticTranslator;
 use Zend_Controller_Action_HelperBroker;
 use Zend_Controller_Front;
 use Zend_Controller_Router_Route;
@@ -15,8 +19,8 @@ use Icinga\Authentication\Auth;
 use Icinga\User;
 use Icinga\Util\DirectoryIterator;
 use Icinga\Util\TimezoneDetect;
-use Icinga\Util\Translator;
 use Icinga\Web\Controller\Dispatcher;
+use Icinga\Web\Menu;
 use Icinga\Web\Navigation\Navigation;
 use Icinga\Web\Notification;
 use Icinga\Web\Session;
@@ -81,12 +85,15 @@ class Web extends EmbeddedWeb
             ->setupZendAutoloader()
             ->setupLogging()
             ->setupErrorHandling()
+            ->loadLibraries()
             ->loadConfig()
+            ->setupLogger()
             ->setupRequest()
             ->setupSession()
             ->setupNotifications()
             ->setupResponse()
             ->setupZendMvc()
+            ->prepareInternationalization()
             ->setupModuleManager()
             ->loadSetupModuleIfNecessary()
             ->loadEnabledModules()
@@ -95,8 +102,8 @@ class Web extends EmbeddedWeb
             ->setupUserBackendFactory()
             ->setupUser()
             ->setupTimezone()
-            ->setupLogger()
-            ->setupInternationalization();
+            ->setupInternationalization()
+            ->setupFatalErrorHandling();
     }
 
     /**
@@ -167,7 +174,7 @@ class Web extends EmbeddedWeb
         return $this->viewRenderer;
     }
 
-    private function hasAccessToSharedNavigationItem(& $config, Config $navConfig)
+    private function hasAccessToSharedNavigationItem(&$config, Config $navConfig)
     {
         // TODO: Provide a more sophisticated solution
 
@@ -280,105 +287,13 @@ class Web extends EmbeddedWeb
     /**
      * Return the app's menu
      *
-     * @return  Navigation
+     * @deprecated Instantiate the returned class directly instead of using this method.
+     *
+     * @return  Menu
      */
     public function getMenu()
     {
-        if ($this->user !== null) {
-            $menu = array(
-                'dashboard' => array(
-                    'label'     => t('Dashboard'),
-                    'url'       => 'dashboard',
-                    'icon'      => 'dashboard',
-                    'priority'  => 10
-                ),
-                'system' => array(
-                    'label'     => t('System'),
-                    'icon'      => 'services',
-                    'priority'  => 700,
-                    'renderer'  => array(
-                        'SummaryNavigationItemRenderer',
-                        'state' => 'critical'
-                    ),
-                    'children'  => array(
-                        'about' => array(
-                            'label'     => t('About'),
-                            'url'       => 'about',
-                            'priority'  => 700
-                        ),
-                        'announcements' => array(
-                            'label'      => t('Announcements'),
-                            'url'        => 'announcements',
-                            'priority'   => 710
-                        )
-                    )
-                ),
-                'configuration' => array(
-                    'label'         => t('Configuration'),
-                    'icon'          => 'wrench',
-                    'permission'    => 'config/*',
-                    'priority'      => 800,
-                    'children'      => array(
-                        'application' => array(
-                            'label'         => t('Application'),
-                            'url'           => 'config/general',
-                            'permission'    => 'config/application/*',
-                            'priority'      => 810
-                        ),
-                        'authentication' => array(
-                            'label'         => t('Authentication'),
-                            'permission'    => 'config/authentication/*',
-                            'priority'      => 830,
-                            'url'           => 'role/list'
-                        ),
-                        'navigation' => array(
-                            'label'         => t('Shared Navigation'),
-                            'url'           => 'navigation/shared',
-                            'permission'    => 'config/application/navigation',
-                            'priority'      => 840,
-                        ),
-                        'modules' => array(
-                            'label'         => t('Modules'),
-                            'url'           => 'config/modules',
-                            'permission'    => 'config/modules',
-                            'priority'      => 890
-                        )
-                    )
-                ),
-                'user' => array(
-                    'cssClass'  => 'user-nav-item',
-                    'label'     => $this->user->getUsername(),
-                    'icon'      => 'user',
-                    'priority'  => 900,
-                    'children'  => array(
-                        'account' => array(
-                            'label'     => t('My Account'),
-                            'priority'  => 100,
-                            'url'       => 'account'
-                        ),
-                        'logout' => array(
-                            'label'         => t('Logout'),
-                            'priority'      => 200,
-                            'attributes'    => array('target' => '_self'),
-                            'url'           => 'authentication/logout'
-                        )
-                    )
-                )
-            );
-
-            if (Logger::writesToFile()) {
-                $menu['system']['children']['application_log'] = array(
-                    'label'      => t('Application Log'),
-                    'url'        => 'list/applicationlog',
-                    'permission' => 'application/log',
-                    'priority'   => 900
-                );
-            }
-        } else {
-            $menu = array();
-        }
-
-        return Navigation::fromArray($menu)->load('menu-item');
+        return new Menu();
     }
 
     /**
@@ -423,6 +338,21 @@ class Web extends EmbeddedWeb
             $user = $auth->getUser();
             $this->getRequest()->setUser($user);
             $this->user = $user;
+
+            if ($user->can('user/application/stacktraces')) {
+                $displayExceptions = $this->user->getPreferences()->getValue(
+                    'icingaweb',
+                    'show_stacktraces'
+                );
+
+                if ($displayExceptions !== null) {
+                    $this->frontController->setParams(
+                        array(
+                            'displayExceptions' => $displayExceptions
+                        )
+                    );
+                }
+            }
         }
         return $this;
     }
@@ -462,13 +392,6 @@ class Web extends EmbeddedWeb
         $this->frontController->setControllerDirectory($this->getApplicationDir('/controllers'));
 
         $displayExceptions = $this->config->get('global', 'show_stacktraces', true);
-        if ($this->user !== null && $this->user->can('application/stacktraces')) {
-            $displayExceptions = $this->user->getPreferences()->getValue(
-                'icingaweb',
-                'show_stacktraces',
-                $displayExceptions
-            );
-        }
 
         $this->frontController->setParams(
             array(
@@ -521,6 +444,37 @@ class Web extends EmbeddedWeb
         return $this;
     }
 
+    /**
+     * Fatal error handling configuration
+     *
+     * @return $this
+     */
+    protected function setupFatalErrorHandling()
+    {
+        register_shutdown_function(function () {
+            $error = error_get_last();
+
+            if ($error !== null && $error['type'] === E_ERROR) {
+                $frontController = Icinga::app()->getFrontController();
+                $response = $frontController->getResponse();
+
+                $response->setException(new ErrorException(
+                    $error['message'],
+                    0,
+                    $error['type'],
+                    $error['file'],
+                    $error['line']
+                ));
+
+                // Clean PHP's fatal error stack trace and replace it with ours
+                ob_end_clean();
+                $frontController->dispatch($frontController->getRequest(), $response);
+            }
+        });
+
+        return $this;
+    }
+
     /**
      * (non-PHPDoc)
      * @see ApplicationBootstrap::detectTimezone() For the method documentation.
@@ -542,9 +496,7 @@ class Web extends EmbeddedWeb
      *
      * Uses the preferred user language or the browser suggested language or our default.
      *
-     * @return  string                      Detected locale code
-     *
-     * @see     Translator::DEFAULT_LOCALE  For the the default locale code.
+     * @return string Detected locale code
      */
     protected function detectLocale()
     {
@@ -554,9 +506,14 @@ class Web extends EmbeddedWeb
         ) {
             return $locale;
         }
+
+        /** @var GettextTranslator $translator */
+        $translator = StaticTranslator::$instance;
+
         if (isset($_SERVER['HTTP_ACCEPT_LANGUAGE'])) {
-            return Translator::getPreferredLocaleCode($_SERVER['HTTP_ACCEPT_LANGUAGE']);
+            return (new Locale())->getPreferred($_SERVER['HTTP_ACCEPT_LANGUAGE'], $translator->listLocales());
         }
-        return Translator::DEFAULT_LOCALE;
+
+        return $translator->getDefaultLocale();
     }
 }
