@@ -4,6 +4,7 @@
 namespace Icinga\Application;
 
 use Icinga\Chart\Inline\PieChart;
+use Icinga\Web\Controller\StaticController;
 use Icinga\Web\JavaScript;
 use Icinga\Web\StyleSheet;
 
@@ -46,17 +47,14 @@ $special = array(
     'css/icinga.css',
     'css/icinga.min.css',
     'js/icinga.dev.js',
-    'js/icinga.ie8.js',
     'js/icinga.min.js'
 );
 
 if (in_array($path, $special)) {
-
     include_once __DIR__ . '/EmbeddedWeb.php';
     EmbeddedWeb::start();
 
-    switch($path) {
-
+    switch ($path) {
         case 'css/icinga.css':
             Stylesheet::send();
             exit;
@@ -65,21 +63,18 @@ if (in_array($path, $special)) {
             exit;
 
         case 'js/icinga.dev.js':
-            JavaScript::send();
+            $forIe11 = (bool) preg_match('/Trident\/7.0;.*rv:11/', $_SERVER['HTTP_USER_AGENT']);
+            JavaScript::send(false, $forIe11);
             exit;
 
         case 'js/icinga.min.js':
-            JavaScript::sendMinified();
-            break;
-
-        case 'js/icinga.ie8.js':
-            JavaScript::sendForIe8();
+            $forIe11 = (bool) preg_match('/Trident\/7.0;.*rv:11/', $_SERVER['HTTP_USER_AGENT']);
+            JavaScript::sendMinified($forIe11);
             break;
 
         default:
             return false;
     }
-
 } elseif ($path === 'svg/chart.php') {
     if (!array_key_exists('data', $_GET)) {
         return false;
@@ -90,7 +85,6 @@ if (in_array($path, $special)) {
     $pie = new PieChart();
     $pie->initFromRequest();
     $pie->toSvg();
-
 } elseif ($path === 'png/chart.php') {
     if (!array_key_exists('data', $_GET)) {
         return false;
@@ -101,11 +95,14 @@ if (in_array($path, $special)) {
     $pie = new PieChart();
     $pie->initFromRequest();
     $pie->toPng();
-
+} elseif (substr($path, 0, 4) === 'lib/') {
+    include_once __DIR__ . '/StaticWeb.php';
+    $app = StaticWeb::start();
+    (new StaticController())->handle($app->getRequest());
+    $app->getResponse()->sendResponse();
 } elseif (file_exists($baseDir . '/' . $path) && is_file($baseDir . '/' . $path)) {
     return false;
 } else {
     include __DIR__ . '/Web.php';
     Web::start()->dispatch();
 }
-
