@@ -251,7 +251,7 @@ class DbQuery extends SimpleQuery
     protected function valueToTimestamp($value)
     {
         // We consider integers as valid timestamps. Does not work for URL params
-        if (ctype_digit($value)) {
+        if (! is_string($value) || ctype_digit($value)) {
             return $value;
         }
         $value = strtotime($value);
@@ -327,13 +327,13 @@ class DbQuery extends SimpleQuery
             return '(' . implode(" $operator ", $sql) . ')';
         } elseif ($sign === '=' && strpos($expression, '*') !== false) {
             if ($expression === '*') {
-                return new Zend_Db_Expr('TRUE');
+                return $col . ' IS NOT NULL';
             }
 
             return $col . ' LIKE ' . $this->escapeForSql($this->escapeWildcards($expression));
         } elseif ($sign === '!=' && strpos($expression, '*') !== false) {
             if ($expression === '*') {
-                return new Zend_Db_Expr('FALSE');
+                return $col . ' IS NULL';
             }
 
             return sprintf(
