@@ -3,6 +3,7 @@
 
 namespace Icinga\Web\Controller;
 
+use ipl\I18n\Translation;
 use Zend_Controller_Action;
 use Zend_Controller_Action_HelperBroker;
 use Zend_Controller_Request_Abstract;
@@ -16,7 +17,6 @@ use Icinga\Exception\ProgrammingError;
 use Icinga\File\Pdf;
 use Icinga\Forms\AutoRefreshForm;
 use Icinga\Security\SecurityException;
-use Icinga\Util\Translator;
 use Icinga\Web\Session;
 use Icinga\Web\Url;
 use Icinga\Web\UrlParams;
@@ -40,6 +40,8 @@ use Icinga\Web\Window;
  */
 class ActionController extends Zend_Controller_Action
 {
+    use Translation;
+
     /**
      * The login route to use when requiring authentication
      */
@@ -64,6 +66,13 @@ class ActionController extends Zend_Controller_Action
      */
     protected $moduleName;
 
+    /**
+     * A page's automatic refresh interval
+     *
+     * The initial value will not be subject to a user's preferences.
+     *
+     * @var int
+     */
     protected $autorefreshInterval;
 
     protected $reloadCss = false;
@@ -124,7 +133,8 @@ class ActionController extends Zend_Controller_Action
 
         $moduleName = $this->getModuleName();
         $this->view->defaultTitle = static::DEFAULT_TITLE;
-        $this->view->translationDomain = $moduleName !== 'default' ? $moduleName : 'icinga';
+        $this->translationDomain = $moduleName !== 'default' ? $moduleName : 'icinga';
+        $this->view->translationDomain = $this->translationDomain;
         $this->_helper->layout()->isIframe = $request->getUrl()->shift('isIframe');
         $this->_helper->layout()->showFullscreen = $request->getUrl()->shift('showFullscreen');
         $this->_helper->layout()->moduleName = $moduleName;
@@ -298,42 +308,6 @@ class ActionController extends Zend_Controller_Action
         return $this->view->tabs;
     }
 
-    /**
-     * Translate a string
-     *
-     * Autoselects the module domain, if any, and falls back to the global one if no translation could be found.
-     *
-     * @param   string      $text       The string to translate
-     * @param   string|null $context    Optional parameter for context based translation
-     *
-     * @return  string                  The translated string
-     */
-    public function translate($text, $context = null)
-    {
-        return Translator::translate($text, $this->view->translationDomain, $context);
-    }
-
-    /**
-     * Translate a plural string
-     *
-     * @param string        $textSingular   The string in singular form to translate
-     * @param string        $textPlural     The string in plural form to translate
-     * @param string        $number         The number to get the plural or singular string
-     * @param string|null   $context        Optional parameter for context based translation
-     *
-     * @return string                       The translated string
-     */
-    public function translatePlural($textSingular, $textPlural, $number, $context = null)
-    {
-        return Translator::translatePlural(
-            $textSingular,
-            $textPlural,
-            $number,
-            $this->view->translationDomain,
-            $context
-        );
-    }
-
     protected function ignoreXhrBody()
     {
         if ($this->isXhr()) {
@@ -341,6 +315,18 @@ class ActionController extends Zend_Controller_Action
         }
     }
 
+    /**
+     * Set the interval (in seconds) at which the page should automatically refresh
+     *
+     * This may be adjusted based on the user's preferences. The result could be a
+     * lower or higher rate of the page's automatic refresh. If this is not desired,
+     * the only way to bypass this is to initialize the {@see ActionController::$autorefreshInterval}
+     * property or to set the `autorefreshInterval` property of the layout directly.
+     *
+     * @param int $interval
+     *
+     * @return $this
+     */
     public function setAutorefreshInterval($interval)
     {
         if (! is_int($interval) || $interval < 1) {
@@ -348,15 +334,22 @@ class ActionController extends Zend_Controller_Action
                 'Setting autorefresh interval smaller than 1 second is not allowed'
             );
         }
+
+        $user = $this->getRequest()->getUser();
+        if ($user !== null) {
+            $speed = (float) $user->getPreferences()->getValue('icingaweb', 'auto_refresh_speed', 1.0);
+            $interval = max(round($interval * $speed), min($interval, 5));
+        }
+
         $this->autorefreshInterval = $interval;
-        $this->_helper->layout()->autorefreshInterval = $interval;
+
         return $this;
     }
 
     public function disableAutoRefresh()
     {
         $this->autorefreshInterval = null;
-        $this->_helper->layout()->autorefreshInterval = null;
+
         return $this;
     }
 
@@ -473,6 +466,10 @@ class ActionController extends Zend_Controller_Action
             }
         }
 
+        if ($this->autorefreshInterval !== null) {
+            $layout->autorefreshInterval = $this->autorefreshInterval;
+        }
+
         if ($req->getParam('error_handler') === null && $req->getParam('format') === 'pdf') {
             $this->sendAsPdf();
             $this->shutdownSession();
