@@ -48,12 +48,28 @@ class Menu extends Navigation
                     'url'         => 'about',
                     'priority'    => 700
                 ],
+                'health' => [
+                    'icon'        => 'eye',
+                    'description' => t('Open health overview'),
+                    'label'       => t('Health'),
+                    'url'         => 'health',
+                    'priority'    => 710,
+                    'renderer'    => 'HealthNavigationRenderer'
+                ],
                 'announcements' => [
                     'icon'        => 'megaphone',
                     'description' => t('List announcements'),
                     'label'       => t('Announcements'),
                     'url'         => 'announcements',
-                    'priority'    => 710
+                    'priority'    => 720
+                ],
+                'sessions' => [
+                    'icon'        => 'host',
+                    'description' => t('List of users who stay logged in'),
+                    'label'       => t('User Sessions'),
+                    'permission'  => 'application/sessions',
+                    'url'         => 'manage-user-devices',
+                    'priority'    => 730
                 ]
             ]
         ]);
@@ -67,24 +83,23 @@ class Menu extends Navigation
                     'icon'        => 'wrench',
                     'description' => t('Open application configuration'),
                     'label'       => t('Application'),
-                    'url'         => 'config/general',
-                    'permission'  => 'config/application/*',
+                    'url'         => 'config',
                     'priority'    => 810
                 ],
                 'authentication' => [
                     'icon'        => 'users',
-                    'description' => t('Open authentication configuration'),
-                    'label'       => t('Authentication'),
-                    'permission'  => 'config/authentication/*',
+                    'description' => t('Open access control configuration'),
+                    'label'       => t('Access Control'),
+                    'permission'  => 'config/access-control/*',
                     'priority'    => 830,
-                    'url'         => 'role/list'
+                    'url'         => 'role'
                 ],
                 'navigation' => [
                     'icon'        => 'sitemap',
                     'description' => t('Open shared navigation configuration'),
                     'label'       => t('Shared Navigation'),
                     'url'         => 'navigation/shared',
-                    'permission'  => 'config/application/navigation',
+                    'permission'  => 'config/navigation',
                     'priority'    => 840,
                 ],
                 'modules' => [
