@@ -4,6 +4,7 @@
 namespace Icinga\Web\Navigation;
 
 use Exception;
+use Icinga\Authentication\Auth;
 use InvalidArgumentException;
 use IteratorAggregate;
 use Icinga\Application\Icinga;
@@ -37,6 +38,13 @@ class NavigationItem implements IteratorAggregate
      */
     protected $active;
 
+    /**
+     * Whether this item is selected
+     *
+     * @var bool
+     */
+    protected $selected;
+
     /**
      * The CSS class used for the outer li element
      *
@@ -88,6 +96,13 @@ class NavigationItem implements IteratorAggregate
      */
     protected $label;
 
+    /**
+     * The item's description
+     *
+     * @var string
+     */
+    protected $description;
+
     /**
      * This item's parent
      *
@@ -153,7 +168,6 @@ class NavigationItem implements IteratorAggregate
      */
     public function init()
     {
-
     }
 
     /**
@@ -207,6 +221,39 @@ class NavigationItem implements IteratorAggregate
         return $this;
     }
 
+    /**
+     * Return whether this item is selected
+     *
+     * @return  bool
+     */
+    public function getSelected()
+    {
+        if ($this->selected === null) {
+            $this->active = false;
+            if ($this->getUrl() !== null && Icinga::app()->getRequest()->getUrl()->matches($this->getUrl())) {
+                $this->setSelected();
+            }
+        }
+
+        return $this->selected;
+    }
+
+    /**
+     * Set whether this item is active
+     *
+     * If it's active and has a parent, the parent gets activated as well.
+     *
+     * @param   bool    $selected
+     *
+     * @return  $this
+     */
+    public function setSelected($selected = true)
+    {
+        $this->selected = (bool) $selected;
+
+        return $this;
+    }
+
     /**
      * Get the CSS class used for the outer li element
      *
@@ -482,6 +529,30 @@ class NavigationItem implements IteratorAggregate
         return $this;
     }
 
+    /**
+     * Get the item's description
+     *
+     * @return  string
+     */
+    public function getDescription()
+    {
+        return $this->description;
+    }
+
+    /**
+     * Set the item's description
+     *
+     * @param   string  $description
+     *
+     * @return  $this
+     */
+    public function setDescription($description)
+    {
+        $this->description = $description;
+
+        return $this;
+    }
+
     /**
      * Set this item's url target
      *
@@ -513,7 +584,7 @@ class NavigationItem implements IteratorAggregate
     public function getUrl()
     {
         if ($this->url === null && $this->hasChildren()) {
-            $this->setUrl(Url::fromPath('#'));
+            $this->setUrl(Url::fromPath('navigation/dashboard', array('name' => strtolower($this->getName()))));
         }
 
         return $this->url;
@@ -531,12 +602,15 @@ class NavigationItem implements IteratorAggregate
     public function setUrl($url)
     {
         if (is_string($url)) {
-            $url = Url::fromPath($url);
-        } elseif (! $url instanceof Url) {
+            $url = Url::fromPath($this->resolveMacros($url));
+        } elseif ($url instanceof Url) {
+            $url = Url::fromPath($this->resolveMacros($url->getAbsoluteUrl()));
+        } else {
             throw new InvalidArgumentException('Argument $url must be of type string or Url');
         }
 
         $this->url = $url;
+
         return $this;
     }
 
@@ -845,4 +919,28 @@ class NavigationItem implements IteratorAggregate
             return IcingaException::describe($e);
         }
     }
+
+    /**
+     * Resolve all macros in the given URL
+     *
+     * @param string $url
+     *
+     * @return  string
+     */
+    protected function resolveMacros($url)
+    {
+        if (strpos($url, '$') === false) {
+            return $url;
+        }
+
+        $macros = [];
+        if (Auth::getInstance()->isAuthenticated()) {
+            $macros['$user.local_name$'] = Auth::getInstance()->getUser()->getLocalUsername();
+        }
+        if (! empty($macros)) {
+            $url = str_replace(array_keys($macros), array_values($macros), $url);
+        }
+
+        return $url;
+    }
 }
