@@ -47,6 +47,13 @@ class Response extends Zend_Controller_Response_Http
      */
     protected $request;
 
+    /**
+     * Whether to instruct the client to reload the window
+     *
+     * @var bool
+     */
+    protected $reloadWindow;
+
     /**
      * Whether to instruct client side script code to reload CSS
      *
@@ -198,6 +205,30 @@ class Response extends Zend_Controller_Response_Http
         return $this->request;
     }
 
+    /**
+     * Get whether to instruct the client to reload the window
+     *
+     * @return bool
+     */
+    public function isWindowReloaded()
+    {
+        return $this->reloadWindow;
+    }
+
+    /**
+     * Set whether to instruct the client to reload the window
+     *
+     * @param bool $reloadWindow
+     *
+     * @return $this
+     */
+    public function setReloadWindow($reloadWindow)
+    {
+        $this->reloadWindow = $reloadWindow;
+
+        return $this;
+    }
+
     /**
      * Get whether to instruct client side script code to reload CSS
      *
@@ -287,6 +318,10 @@ class Response extends Zend_Controller_Response_Http
         $redirectUrl = $this->getRedirectUrl();
         if ($this->getRequest()->isXmlHttpRequest()) {
             if ($redirectUrl !== null) {
+                if ($this->getRequest()->isGet() && Icinga::app()->getViewRenderer()->view->compact) {
+                    $redirectUrl->getParams()->set('showCompact', true);
+                }
+
                 $this->setHeader('X-Icinga-Redirect', rawurlencode($redirectUrl->getAbsoluteUrl()), true);
                 if ($this->getRerenderLayout()) {
                     $this->setHeader('X-Icinga-Rerender-Layout', 'yes', true);
@@ -298,6 +333,9 @@ class Response extends Zend_Controller_Response_Http
             if ($this->getRerenderLayout()) {
                 $this->setHeader('X-Icinga-Container', 'layout', true);
             }
+            if ($this->isWindowReloaded()) {
+                $this->setHeader('X-Icinga-Reload-Window', 'yes', true);
+            }
             if ($this->isReloadCss()) {
                 $this->setHeader('X-Icinga-Reload-Css', 'now', true);
             }
