@@ -8,7 +8,7 @@ use Icinga\Data\Filter\Filter;
 use Icinga\Forms\Announcement\AcknowledgeAnnouncementForm;
 use Icinga\Web\Announcement\AnnouncementCookie;
 use Icinga\Web\Announcement\AnnouncementIniRepository;
-use Icinga\Web\Helper\HtmlPurifier;
+use Icinga\Web\Helper\Markdown;
 
 /**
  * Render announcements
@@ -36,13 +36,12 @@ class Announcements extends AbstractWidget
         $announcements = $repo->findActive();
         $announcements->applyFilter($acked);
         if ($announcements->hasResult()) {
-            $purifier = new HtmlPurifier(array('HTML.Allowed' => 'b,a[href|target],i,*[class]'));
-            $html = '<ul role="alert" id="announcements">';
+            $html = '<ul role="alert">';
             foreach ($announcements as $announcement) {
                 $ackForm = new AcknowledgeAnnouncementForm();
                 $ackForm->populate(array('hash' => $announcement->hash));
-                $html .= '<li><div>'
-                    . $purifier->purify($announcement->message)
+                $html .= '<li><div class="message">'
+                    . Markdown::text($announcement->message)
                     . '</div>'
                     . $ackForm
                     . '</li>';
