@@ -8,6 +8,7 @@ use Icinga\Data\ResourceFactory;
 use Icinga\Exception\ConfigurationError;
 use Icinga\Exception\NotFoundError;
 use Icinga\Forms\ConfirmRemovalForm;
+use Icinga\Module\Monitoring\Forms\Config\TransportReorderForm;
 use Icinga\Web\Controller;
 use Icinga\Web\Notification;
 use Icinga\Module\Monitoring\Backend;
@@ -26,6 +27,8 @@ class ConfigController extends Controller
     public function init()
     {
         $this->assertPermission('config/modules');
+        $this->view->title = $this->translate('Backends');
+        $this->view->defaultTitle = 'monitoring :: ' . $this->view->defaultTitle;
         parent::init();
     }
 
@@ -34,8 +37,10 @@ class ConfigController extends Controller
      */
     public function indexAction()
     {
+        $this->view->commandTransportReorderForm = $form = new TransportReorderForm();
+        $form->handleRequest();
+
         $this->view->backendsConfig = $this->Config('backends');
-        $this->view->transportConfig = $this->Config('commandtransports');
         $this->view->tabs = $this->Module()->getConfigTabs()->activate('backends');
     }
 
@@ -96,7 +101,7 @@ class ConfigController extends Controller
         try {
             $form->setResourceConfig(ResourceFactory::getResourceConfigs());
         } catch (ConfigurationError $e) {
-            if ($this->hasPermission('config/application/resources')) {
+            if ($this->hasPermission('config/resources')) {
                 Notification::error($e->getMessage());
                 $this->redirectNow('config/createresource');
             }
@@ -287,6 +292,7 @@ class ConfigController extends Controller
         $form->handleRequest();
 
         $this->view->form = $form;
+        $this->view->title = $this->translate('Security');
         $this->view->tabs = $this->Module()->getConfigTabs()->activate('security');
     }
 }
