@@ -3,6 +3,9 @@
 
 namespace Icinga\Module\Monitoring\Controllers;
 
+use Icinga\Security\SecurityException;
+use Icinga\Util\GlobFilter;
+use Icinga\Web\Form;
 use Zend_Form;
 use Icinga\Data\Filter\Filter;
 use Icinga\Module\Monitoring\Backend;
@@ -76,13 +79,12 @@ class ListController extends Controller
             'host_last_state_change' => $stateChangeColumn,
             'host_notifications_enabled',
             'host_active_checks_enabled',
-            'host_passive_checks_enabled'
+            'host_passive_checks_enabled',
+            'host_check_command',
+            'host_next_update'
         ), $this->addColumns()));
-        $this->applyRestriction('monitoring/filter/objects', $hosts);
-        $this->filterQuery($hosts);
 
         $this->setupPaginationControl($hosts);
-        $this->setupLimitControl();
         $this->setupSortControl(array(
             'host_severity'             => $this->translate('Severity'),
             'host_state'                => $this->translate('Current State'),
@@ -91,6 +93,8 @@ class ListController extends Controller
             'host_last_check'           => $this->translate('Last Check'),
             'host_last_state_change'    => $this->translate('Last State Change')
         ), $hosts);
+        $this->filterQuery($hosts);
+        $this->setupLimitControl();
 
         $stats = $this->backend->select()->from('hoststatussummary', array(
             'hosts_total',
@@ -106,7 +110,6 @@ class ListController extends Controller
         $this->applyRestriction('monitoring/filter/objects', $stats);
 
         $summary = $hosts->getQuery()->queryServiceProblemSummary();
-        $this->applyRestriction('monitoring/filter/objects', $summary);
 
         $this->view->hosts = $hosts;
         $this->view->stats = $stats;
@@ -157,13 +160,12 @@ class ListController extends Controller
             'service_severity',
             'service_notifications_enabled',
             'service_active_checks_enabled',
-            'service_passive_checks_enabled'
+            'service_passive_checks_enabled',
+            'service_check_command',
+            'service_next_update'
         ), $this->addColumns()));
-        $this->applyRestriction('monitoring/filter/objects', $services);
-        $this->filterQuery($services);
 
         $this->setupPaginationControl($services);
-        $this->setupLimitControl();
         $this->setupSortControl(array(
             'service_severity'          => $this->translate('Service Severity'),
             'service_state'             => $this->translate('Current Service State'),
@@ -176,6 +178,8 @@ class ListController extends Controller
             'host_address'              => $this->translate('Host Address'),
             'host_last_check'           => $this->translate('Last Host Check')
         ), $services);
+        $this->filterQuery($services);
+        $this->setupLimitControl();
 
         $stats = $this->backend->select()->from('servicestatussummary', array(
             'services_critical',
@@ -237,11 +241,8 @@ class ListController extends Controller
             'host_display_name',
             'service_display_name'
         ));
-        $this->applyRestriction('monitoring/filter/objects', $downtimes);
-        $this->filterQuery($downtimes);
 
         $this->setupPaginationControl($downtimes);
-        $this->setupLimitControl();
         $this->setupSortControl(array(
             'downtime_is_in_effect'     => $this->translate('Is In Effect'),
             'host_display_name'         => $this->translate('Host'),
@@ -254,6 +255,8 @@ class ListController extends Controller
             'downtime_scheduled_end'    => $this->translate('Scheduled End'),
             'downtime_duration'         => $this->translate('Duration')
         ), $downtimes);
+        $this->filterQuery($downtimes);
+        $this->setupLimitControl();
 
         $this->view->downtimes = $downtimes;
 
@@ -277,6 +280,7 @@ class ListController extends Controller
         $this->setAutorefreshInterval(15);
 
         $notifications = $this->backend->select()->from('notification', array(
+            'id',
             'host_display_name',
             'host_name',
             'notification_contact_name',
@@ -286,14 +290,13 @@ class ListController extends Controller
             'service_description',
             'service_display_name'
         ));
-        $this->applyRestriction('monitoring/filter/objects', $notifications);
-        $this->filterQuery($notifications);
 
         $this->setupPaginationControl($notifications);
-        $this->setupLimitControl();
         $this->setupSortControl(array(
             'notification_timestamp' => $this->translate('Notification Start')
         ), $notifications);
+        $this->filterQuery($notifications);
+        $this->setupLimitControl();
 
         $this->view->notifications = $notifications;
     }
@@ -303,6 +306,10 @@ class ListController extends Controller
      */
     public function contactsAction()
     {
+        if (! $this->hasPermission('*') && $this->hasPermission('no-monitoring/contacts')) {
+            throw new SecurityException('No permission for %s', 'monitoring/contacts');
+        }
+
         $this->addTitleTab(
             'contacts',
             $this->translate('Contacts'),
@@ -317,17 +324,16 @@ class ListController extends Controller
             'contact_notify_service_timeperiod',
             'contact_notify_host_timeperiod'
         ));
-        $this->applyRestriction('monitoring/filter/objects', $contacts);
-        $this->filterQuery($contacts);
 
         $this->setupPaginationControl($contacts);
-        $this->setupLimitControl();
         $this->setupSortControl(array(
             'contact_name'  => $this->translate('Name'),
             'contact_alias' => $this->translate('Alias'),
             'contact_email' => $this->translate('Email'),
             'contact_pager' => $this->translate('Pager Address / Number')
         ), $contacts);
+        $this->filterQuery($contacts);
+        $this->setupLimitControl();
 
         $this->view->contacts = $contacts;
     }
@@ -344,7 +350,9 @@ class ListController extends Controller
         $form->render();
         $this->view->form = $form;
 
-        $this->params->remove('view');
+        $this->params
+            ->remove('showCompact')
+            ->remove('format');
         $orientation = $this->params->shift('vertical', 0) ? 'vertical' : 'horizontal';
 /*
         $orientationBox = new SelectBox(
@@ -358,13 +366,16 @@ class ListController extends Controller
         );
         $orientationBox->applyRequest($this->getRequest());
 */
+        $objectType = $form->getValue('objecttype');
+        $from = $form->getValue('from');
         $query = $this->backend->select()->from(
-            'eventgrid',
+            'eventgrid' . $objectType,
             array('day', $form->getValue('state'))
         );
         $this->params->remove(array('objecttype', 'from', 'to', 'state', 'btn_submit'));
         $this->view->filter = Filter::fromQuerystring((string) $this->params);
         $query->applyFilter($this->view->filter);
+        $query->applyFilter(Filter::fromQuerystring('timestamp>=' . $from));
         $this->applyRestriction('monitoring/filter/objects', $query);
         $this->view->summary = $query;
         $this->view->column = $form->getValue('state');
@@ -377,6 +388,10 @@ class ListController extends Controller
      */
     public function contactgroupsAction()
     {
+        if (! $this->hasPermission('*') && $this->hasPermission('no-monitoring/contacts')) {
+            throw new SecurityException('No permission for %s', 'monitoring/contacts');
+        }
+
         $this->addTitleTab(
             'contactgroups',
             $this->translate('Contact Groups'),
@@ -388,15 +403,14 @@ class ListController extends Controller
             'contactgroup_alias',
             'contact_count'
         ));
-        $this->applyRestriction('monitoring/filter/objects', $contactGroups);
-        $this->filterQuery($contactGroups);
 
         $this->setupPaginationControl($contactGroups);
-        $this->setupLimitControl();
         $this->setupSortControl(array(
             'contactgroup_name'     => $this->translate('Contactgroup Name'),
             'contactgroup_alias'    => $this->translate('Contactgroup Alias')
         ), $contactGroups);
+        $this->filterQuery($contactGroups);
+        $this->setupLimitControl();
 
         $this->view->contactGroups = $contactGroups;
     }
@@ -429,11 +443,8 @@ class ListController extends Controller
             'host_display_name',
             'service_display_name'
         ));
-        $this->applyRestriction('monitoring/filter/objects', $comments);
-        $this->filterQuery($comments);
 
         $this->setupPaginationControl($comments);
-        $this->setupLimitControl();
         $this->setupSortControl(
             array(
                 'comment_timestamp'     => $this->translate('Comment Timestamp'),
@@ -444,6 +455,8 @@ class ListController extends Controller
             ),
             $comments
         );
+        $this->filterQuery($comments);
+        $this->setupLimitControl();
 
         $this->view->comments = $comments;
 
@@ -479,16 +492,52 @@ class ListController extends Controller
             'services_warning_handled',
             'services_warning_unhandled'
         ));
-        $this->applyRestriction('monitoring/filter/objects', $serviceGroups);
-        $this->filterQuery($serviceGroups);
 
         $this->setupPaginationControl($serviceGroups);
-        $this->setupLimitControl();
         $this->setupSortControl(array(
-            'services_severity'     => $this->translate('Severity'),
             'servicegroup_alias'    => $this->translate('Service Group Name'),
+            'services_severity'     => $this->translate('Severity'),
             'services_total'        => $this->translate('Total Services')
         ), $serviceGroups);
+        $this->filterQuery($serviceGroups);
+        $this->setupLimitControl();
+
+        $this->view->serviceGroups = $serviceGroups;
+    }
+
+    /**
+     * List service groups
+     */
+    public function servicegroupGridAction()
+    {
+        $this->addTitleTab(
+            'servicegroup-grid',
+            $this->translate('Service Group Grid'),
+            $this->translate('Show the Service Group Grid')
+        );
+
+        $this->setAutorefreshInterval(15);
+
+        $serviceGroups = $this->backend->select()->from('servicegroupsummary', array(
+            'servicegroup_alias',
+            'servicegroup_name',
+            'services_critical_handled',
+            'services_critical_unhandled',
+            'services_ok',
+            'services_pending',
+            'services_total',
+            'services_unknown_handled',
+            'services_unknown_unhandled',
+            'services_warning_handled',
+            'services_warning_unhandled'
+        ));
+        $this->filterQuery($serviceGroups);
+
+        $this->setupSortControl(array(
+            'servicegroup_alias'    => $this->translate('Service Group Name'),
+            'services_severity'     => $this->translate('Severity'),
+            'services_total'        => $this->translate('Total Services')
+        ), $serviceGroups, ['services_severity' => 'desc']);
 
         $this->view->serviceGroups = $serviceGroups;
     }
@@ -526,17 +575,52 @@ class ListController extends Controller
             'services_warning_handled',
             'services_warning_unhandled'
         ));
-        $this->applyRestriction('monitoring/filter/objects', $hostGroups);
-        $this->filterQuery($hostGroups);
 
         $this->setupPaginationControl($hostGroups);
-        $this->setupLimitControl();
         $this->setupSortControl(array(
+            'hostgroup_alias'   => $this->translate('Host Group Name'),
+            'hosts_severity'    => $this->translate('Severity'),
+            'hosts_total'       => $this->translate('Total Hosts'),
+            'services_total'    => $this->translate('Total Services')
+        ), $hostGroups);
+        $this->filterQuery($hostGroups);
+        $this->setupLimitControl();
+
+        $this->view->hostGroups = $hostGroups;
+    }
+
+    /**
+     * List host groups
+     */
+    public function hostgroupGridAction()
+    {
+        $this->addTitleTab(
+            'hostgroup-grid',
+            $this->translate('Host Group Grid'),
+            $this->translate('Show the Host Group Grid')
+        );
+
+        $this->setAutorefreshInterval(15);
+
+        $hostGroups = $this->backend->select()->from('hostgroupsummary', [
+            'hostgroup_alias',
+            'hostgroup_name',
+            'hosts_down_handled',
+            'hosts_down_unhandled',
+            'hosts_pending',
+            'hosts_total',
+            'hosts_unreachable_handled',
+            'hosts_unreachable_unhandled',
+            'hosts_up'
+        ]);
+        $this->filterQuery($hostGroups);
+
+        $this->setupSortControl([
             'hosts_severity'    => $this->translate('Severity'),
             'hostgroup_alias'   => $this->translate('Host Group Name'),
             'hosts_total'       => $this->translate('Total Hosts'),
             'services_total'    => $this->translate('Total Services')
-        ), $hostGroups);
+        ], $hostGroups, ['hosts_severity' => 'desc']);
 
         $this->view->hostGroups = $hostGroups;
     }
@@ -550,6 +634,7 @@ class ListController extends Controller
         );
 
         $query = $this->backend->select()->from('eventhistory', array(
+            'id',
             'host_name',
             'host_display_name',
             'service_description',
@@ -561,18 +646,21 @@ class ListController extends Controller
             'type'
         ));
 
-        $this->applyRestriction('monitoring/filter/objects', $query);
-        $this->filterQuery($query);
         $this->view->history = $query;
 
-        $this->setupLimitControl();
         $this->setupSortControl(array(
             'timestamp' => $this->translate('Occurence')
         ), $query);
+        $this->filterQuery($query);
+        $this->setupLimitControl();
     }
 
     public function servicegridAction()
     {
+        if ($this->params->has('noscript_apply')) {
+            $this->redirectNow($this->getRequest()->getUrl()->without('noscript_apply'));
+        }
+
         $this->addTitleTab('servicegrid', $this->translate('Service Grid'), $this->translate('Show the Service Grid'));
         $this->setAutorefreshInterval(15);
         $query = $this->backend->select()->from('servicestatus', array(
@@ -584,18 +672,42 @@ class ListController extends Controller
             'service_output',
             'service_state'
         ));
-        $this->applyRestriction('monitoring/filter/objects', $query);
         $this->filterQuery($query);
         $filter = (bool) $this->params->shift('problems', false) ? Filter::where('service_problem', 1) : null;
-        $pivot = $query
-            ->pivot(
-                'service_description',
-                'host_name',
-                $filter,
-                $filter ? clone $filter : null
-            )
-            ->setXAxisHeader('service_display_name')
-            ->setYAxisHeader('host_display_name');
+
+        $this->view->problemToggle = $problemToggle = new Form(['method' => 'GET']);
+        $problemToggle->setUidDisabled();
+        $problemToggle->setTokenDisabled();
+        $problemToggle->setAttrib('class', 'filter-toggle inline icinga-controls');
+        $problemToggle->addElement('checkbox', 'problems', [
+            'disableHidden' => true,
+            'autosubmit'    => true,
+            'value'         => $filter !== null,
+            'label'         => $this->translate('Problems Only'),
+            'decorators'    => ['ViewHelper', ['Label', ['placement' => 'APPEND']]]
+        ]);
+
+        if ($this->params->get('flipped', false)) {
+            $pivot = $query
+                ->pivot(
+                    'host_name',
+                    'service_description',
+                    $filter,
+                    $filter ? clone $filter : null
+                )
+                ->setYAxisHeader('service_display_name')
+                ->setXAxisHeader('host_display_name');
+        } else {
+            $pivot = $query
+                ->pivot(
+                    'service_description',
+                    'host_name',
+                    $filter,
+                    $filter ? clone $filter : null
+                )
+                ->setXAxisHeader('service_display_name')
+                ->setYAxisHeader('host_display_name');
+        }
         $this->setupSortControl(array(
             'host_display_name'     => $this->translate('Hostname'),
             'service_display_name'  => $this->translate('Service Name')
@@ -605,6 +717,9 @@ class ListController extends Controller
         list($pivotData, $pivotHeader) = $pivot->toArray();
         $this->view->pivotData = $pivotData;
         $this->view->pivotHeader = $pivotHeader;
+        if ($this->params->get('flipped', false)) {
+            $this->render('servicegrid-flipped');
+        }
     }
 
     /**
@@ -620,9 +735,16 @@ class ListController extends Controller
             'format', // handleFormatRequest()
             'stateType', // hostsAction() and servicesAction()
             'addColumns', // addColumns()
-            'problems' // servicegridAction()
+            'problems', // servicegridAction()
+            'flipped' // servicegridAction()
         ));
+
+        if ($this->params->get('format') !== 'sql' || $this->hasPermission('config/authentication/roles/show')) {
+            $this->applyRestriction('monitoring/filter/objects', $dataView);
+        }
+
         $this->handleFormatRequest($dataView);
+
         return $dataView;
     }
 
@@ -640,8 +762,31 @@ class ListController extends Controller
             -1,
             PREG_SPLIT_NO_EMPTY
         );
-        $this->view->addColumns = $columns;
-        return $columns;
+
+        $customVars = [];
+        $additionalCols = [];
+        foreach ($columns as $column) {
+            if (preg_match('~^_(host|service)_([a-zA-Z0-9_]+)$~', $column, $m)) {
+                $customVars[$m[1]]['vars'][$m[2]] = null;
+            } else {
+                $additionalCols[] = $column;
+            }
+        }
+
+        if (! empty($customVars)) {
+            $blacklistedProperties = new GlobFilter(
+                $this->getRestrictions('monitoring/blacklist/properties')
+            );
+            $customVars = $blacklistedProperties->removeMatching($customVars);
+            foreach ($customVars as $type => $vars) {
+                foreach ($vars['vars'] as $var => $_) {
+                    $additionalCols[] = '_' . $type . '_' . $var;
+                }
+            }
+        }
+
+        $this->view->addColumns = $additionalCols;
+        return $additionalCols;
     }
 
     protected function addTitleTab($action, $title, $tip)
