@@ -30,11 +30,11 @@ class DeleteDowntimesCommandForm extends CommandForm
     /**
      * Set the downtimes to delete
      *
-     * @param   array $downtimes
+     * @param   iterable $downtimes
      *
      * @return  $this
      */
-    public function setDowntimes(array $downtimes)
+    public function setDowntimes($downtimes)
     {
         $this->downtimes = $downtimes;
         return $this;
@@ -73,6 +73,7 @@ class DeleteDowntimesCommandForm extends CommandForm
             $delDowntime
                 ->setDowntimeId($downtime->id)
                 ->setDowntimeName($downtime->name)
+                ->setAuthor($this->Auth()->getUser()->getUsername())
                 ->setIsService(isset($downtime->service_description));
             $this->getTransport($this->request)->send($delDowntime);
         }
