@@ -12,7 +12,6 @@ use Icinga\Data\Selectable;
 use Icinga\Exception\ConfigurationError;
 use Icinga\Exception\ProgrammingError;
 
-
 class MonitoringBackend implements Selectable, Queryable, ConnectionInterface
 {
     /**
@@ -74,7 +73,6 @@ class MonitoringBackend implements Selectable, Queryable, ConnectionInterface
     public static function instance($name = null)
     {
         if (! array_key_exists($name, self::$instances)) {
-
             list($foundName, $config) = static::loadConfig($name);
             $type = $config->get('type');
             $class = implode(
@@ -162,7 +160,6 @@ class MonitoringBackend implements Selectable, Queryable, ConnectionInterface
         $backends = Config::module('monitoring', 'backends');
 
         if ($name === null) {
-
             $count = 0;
 
             foreach ($backends as $name => $config) {
@@ -179,9 +176,7 @@ class MonitoringBackend implements Selectable, Queryable, ConnectionInterface
             }
 
             throw new ConfigurationError($message);
-
         } else {
-
             $config = $backends->getSection($name);
 
             if ($config->isEmpty()) {
@@ -227,7 +222,11 @@ class MonitoringBackend implements Selectable, Queryable, ConnectionInterface
     public function getResource()
     {
         if ($this->resource === null) {
-            $this->resource = ResourceFactory::create($this->config->get('resource'));
+            $config = ResourceFactory::getResourceConfig($this->config->get('resource'));
+            if ($this->is('ido') && $config->type === 'db' && $config->db === 'mysql' && $config->charset === null) {
+                $config->charset = 'latin1';
+            }
+            $this->resource = ResourceFactory::createResource($config);
             if ($this->is('ido') && $this->resource->getDbType() !== 'oracle') {
                 // TODO(el): The resource should set the table prefix
                 $this->resource->setTablePrefix('icinga_');
@@ -339,7 +338,11 @@ class MonitoringBackend implements Selectable, Queryable, ConnectionInterface
      */
     public function getProgramVersion()
     {
-        return preg_replace('/^[vr]/', '', $this->select()->from('programstatus', array('program_version'))->fetchOne());
+        return preg_replace(
+            '/^[vr]/',
+            '',
+            $this->select()->from('programstatus', array('program_version'))->fetchOne()
+        );
     }
 
     /**
@@ -355,7 +358,7 @@ class MonitoringBackend implements Selectable, Queryable, ConnectionInterface
             $programVersion = $this->select()->from('programstatus', array('program_version'))->fetchOne();
         }
         return (bool) preg_match(
-            '/^[vr]2\.\d+\.\d+.*$/',
+            '/^[vr]?2\.\d+\.\d+.*$/',
             $programVersion
         );
     }
