@@ -3,10 +3,12 @@
 
 namespace Icinga\Module\Monitoring\Command\Renderer;
 
+use Icinga\Module\Monitoring\Backend\MonitoringBackend;
 use Icinga\Module\Monitoring\Command\IcingaApiCommand;
 use Icinga\Module\Monitoring\Command\Instance\ToggleInstanceFeatureCommand;
 use Icinga\Module\Monitoring\Command\Object\AcknowledgeProblemCommand;
 use Icinga\Module\Monitoring\Command\Object\AddCommentCommand;
+use Icinga\Module\Monitoring\Command\Object\ApiScheduleHostDowntimeCommand;
 use Icinga\Module\Monitoring\Command\Object\DeleteCommentCommand;
 use Icinga\Module\Monitoring\Command\Object\DeleteDowntimeCommand;
 use Icinga\Module\Monitoring\Command\Object\ProcessCheckResultCommand;
@@ -99,6 +101,11 @@ class IcingaApiCommandRenderer implements IcingaCommandRendererInterface
             'author'    => $command->getAuthor(),
             'comment'   => $command->getComment()
         );
+
+        if ($command->getExpireTime() !== null) {
+            $data['expiry'] = $command->getExpireTime();
+        }
+
         $this->applyFilter($data, $command->getObject());
         return IcingaApiCommand::create($endpoint, $data);
     }
@@ -151,25 +158,40 @@ class IcingaApiCommandRenderer implements IcingaCommandRendererInterface
             'trigger_name'  => $command->getTriggerId()
         );
         $commandData = $data;
+
         if ($command instanceof PropagateHostDowntimeCommand) {
-            /** @var \Icinga\Module\Monitoring\Command\Object\PropagateHostDowntimeCommand $command */
             $commandData['child_options'] = $command->getTriggered() ? 1 : 2;
+        } elseif ($command instanceof ApiScheduleHostDowntimeCommand) {
+            // We assume that it has previously been verified that the Icinga version is
+            // equal to or greater than 2.11.0
+            $commandData['child_options'] = $command->getChildOptions();
         }
+
+        $allServicesCompat = false;
+        if ($command instanceof ScheduleHostDowntimeCommand) {
+            if ($command->isForAllServicesNative()) {
+                // We assume that it has previously been verified that the Icinga version is
+                // equal to or greater than 2.11.0
+                $commandData['all_services'] = $command->getForAllServices();
+            } else {
+                $allServicesCompat = $command->getForAllServices();
+            }
+        }
+
         $this->applyFilter($commandData, $command->getObject());
         $apiCommand = IcingaApiCommand::create($endpoint, $commandData);
-        if ($command instanceof ScheduleHostDowntimeCommand
-            /** @var \Icinga\Module\Monitoring\Command\Object\ScheduleHostDowntimeCommand $command */
-            && $command->getForAllServices()
-        ) {
-            $commandData = $data + array(
-                'type'          => 'Service',
-                'filter'        => 'host.name == host_name',
-                'filter_vars'   => array(
+
+        if ($allServicesCompat) {
+            $commandData = $data + [
+                'type'        => 'Service',
+                'filter'      => 'host.name == host_name',
+                'filter_vars' => [
                     'host_name' => $command->getObject()->getName()
-                )
-            );
+                ]
+            ];
             $apiCommand->setNext(IcingaApiCommand::create($endpoint, $commandData));
         }
+
         return $apiCommand;
     }
 
@@ -237,25 +259,27 @@ class IcingaApiCommandRenderer implements IcingaCommandRendererInterface
     public function renderDeleteComment(DeleteCommentCommand $command)
     {
         $endpoint = 'actions/remove-comment';
-        $data = array(
-            'comment' => $command->getCommentName()
-        );
+        $data = [
+            'author'    => $command->getAuthor(),
+            'comment'   => $command->getCommentName()
+        ];
         return IcingaApiCommand::create($endpoint, $data);
     }
 
     public function renderDeleteDowntime(DeleteDowntimeCommand $command)
     {
         $endpoint = 'actions/remove-downtime';
-        $data = array(
-            'downtime' => $command->getDowntimeName()
-        );
+        $data = [
+            'author'    => $command->getAuthor(),
+            'downtime'  => $command->getDowntimeName()
+        ];
         return IcingaApiCommand::create($endpoint, $data);
     }
 
     public function renderRemoveAcknowledgement(RemoveAcknowledgementCommand $command)
     {
         $endpoint = 'actions/remove-acknowledgement';
-        $data = array();
+        $data = ['author' => $command->getAuthor()];
         $this->applyFilter($data, $command->getObject());
         return IcingaApiCommand::create($endpoint, $data);
     }
