@@ -61,18 +61,14 @@ class Perfdata
     /**
      * The WARNING threshold
      *
-     * TODO: Should be parsed Range-Object instead of string
-     *
-     * @var string
+     * @var ThresholdRange
      */
     protected $warningThreshold;
 
     /**
      * The CRITICAL threshold
      *
-     * TODO: Should be parsed Range-Object instead of string
-     *
-     * @var string
+     * @var ThresholdRange
      */
     protected $criticalThreshold;
 
@@ -96,6 +92,15 @@ class Perfdata
                 $this->maxValue = 100.0;
             }
         }
+
+        $warn = $this->warningThreshold->getMax();
+        if ($warn !== null) {
+            $crit = $this->criticalThreshold->getMax();
+            if ($crit !== null && $warn > $crit) {
+                $this->warningThreshold->setInverted();
+                $this->criticalThreshold->setInverted();
+            }
+        }
     }
 
     /**
@@ -111,7 +116,7 @@ class Perfdata
     {
         if (empty($perfdata)) {
             throw new InvalidArgumentException('Perfdata::fromString expects a string with content');
-        } elseif (false === strpos($perfdata, '=')) {
+        } elseif (strpos($perfdata, '=') === false) {
             throw new InvalidArgumentException(
                 'Perfdata::fromString expects a key=value formatted string. Got "' . $perfdata . '" instead'
             );
@@ -141,6 +146,16 @@ class Perfdata
         return in_array($this->unit, array('s', 'ms', 'us'));
     }
 
+    /**
+     * Return whether this performance data's value is a temperature
+     *
+     * @return  bool    True in case it's temperature, otherwise False
+     */
+    public function isTemperature()
+    {
+        return in_array($this->unit, array('°c', '°f'));
+    }
+
     /**
      * Return whether this performance data's value is in percentage
      *
@@ -199,6 +214,16 @@ class Perfdata
         return $this->value;
     }
 
+    /**
+     * Return the unit as a string
+     *
+     * @return string
+     */
+    public function getUnit()
+    {
+        return $this->unit;
+    }
+
     /**
      * Return the value as percentage (0-100)
      *
@@ -211,8 +236,8 @@ class Perfdata
         }
 
         if ($this->maxValue !== null) {
-            $minValue = $this->minValue !== null ? $this->minValue : 0;
-            if ((float) ($this->maxValue - $minValue) === 0.0) {
+            $minValue = $this->minValue !== null ? $this->minValue : 0.0;
+            if ($this->maxValue == $minValue) {
                 return null;
             }
 
@@ -223,9 +248,9 @@ class Perfdata
     }
 
     /**
-     * Return this performance data's warning treshold or null if it is not available
+     * Return this performance data's warning treshold
      *
-     * @return  null|string
+     * @return  ThresholdRange
      */
     public function getWarningThreshold()
     {
@@ -233,9 +258,9 @@ class Perfdata
     }
 
     /**
-     * Return this performance data's critical treshold or null if it is not available
+     * Return this performance data's critical treshold
      *
-     * @return  null|string
+     * @return  ThresholdRange
      */
     public function getCriticalThreshold()
     {
@@ -282,27 +307,43 @@ class Perfdata
         $parts = explode(';', $this->perfdataValue);
 
         $matches = array();
-        if (preg_match('@^(-?\d+(\.\d+)?)([a-zA-Z%]{1,2})$@', $parts[0], $matches)) {
+        if (preg_match('@^(-?\d+(\.\d+)?)([a-zA-Z%°]{1,2})$@u', $parts[0], $matches)) {
             $this->unit = strtolower($matches[3]);
             $this->value = self::convert($matches[1], $this->unit);
         } else {
             $this->value = self::convert($parts[0]);
         }
 
-        switch (count($parts))
-        {
+        switch (count($parts)) {
+            /* @noinspection PhpMissingBreakStatementInspection */
             case 5:
                 if ($parts[4] !== '') {
                     $this->maxValue = self::convert($parts[4], $this->unit);
                 }
+            /* @noinspection PhpMissingBreakStatementInspection */
             case 4:
                 if ($parts[3] !== '') {
                     $this->minValue = self::convert($parts[3], $this->unit);
                 }
+            /* @noinspection PhpMissingBreakStatementInspection */
             case 3:
-                $this->criticalThreshold = trim($parts[2]) ? trim($parts[2]) : null;
+                $this->criticalThreshold = self::convert(
+                    ThresholdRange::fromString(trim($parts[2])),
+                    $this->unit
+                );
+                // Fallthrough
             case 2:
-                $this->warningThreshold = trim($parts[1]) ? trim($parts[1]) : null;
+                $this->warningThreshold = self::convert(
+                    ThresholdRange::fromString(trim($parts[1])),
+                    $this->unit
+                );
+        }
+
+        if ($this->warningThreshold === null) {
+            $this->warningThreshold = new ThresholdRange();
+        }
+        if ($this->criticalThreshold === null) {
+            $this->criticalThreshold = new ThresholdRange();
         }
     }
 
@@ -316,9 +357,24 @@ class Perfdata
      */
     protected static function convert($value, $fromUnit = null)
     {
+        if ($value instanceof ThresholdRange) {
+            $value = clone $value;
+
+            $min = $value->getMin();
+            if ($min !== null) {
+                $value->setMin(self::convert($min, $fromUnit));
+            }
+
+            $max = $value->getMax();
+            if ($max !== null) {
+                $value->setMax(self::convert($max, $fromUnit));
+            }
+
+            return $value;
+        }
+
         if (is_numeric($value)) {
-            switch ($fromUnit)
-            {
+            switch ($fromUnit) {
                 case 'us':
                     return $value / pow(10, 6);
                 case 'ms':
@@ -341,53 +397,21 @@ class Perfdata
     {
         $rawValue = $this->getValue();
         $minValue = $this->getMinimumValue() !== null ? $this->getMinimumValue() : 0;
-        $maxValue = $this->getMaximumValue();
         $usedValue = ($rawValue - $minValue);
-        $unusedValue = ($maxValue - $minValue) - $usedValue;
 
-        $warningThreshold = $this->convert($this->warningThreshold, $this->unit);
-        $criticalThreshold = $this->convert($this->criticalThreshold, $this->unit);
-
-        $gray = $unusedValue;
         $green = $orange = $red = 0;
 
-        $pieState = self::PERFDATA_OK;
-        if ($warningThreshold > $criticalThreshold) {
-            // inverted threshold parsing OK > warning > critical
-            if (isset($warningThreshold) && $this->value <= $warningThreshold) {
-                $pieState = self::PERFDATA_WARNING;
-            }
-            if (isset($criticalThreshold) && $this->value <= $criticalThreshold) {
-                $pieState = self::PERFDATA_CRITICAL;
-            }
-
-        } else {
-            // TODO: Use standard perfdata range format to decide the state #8194
-
-            // regular threshold parsing  OK < warning < critical
-            if (isset($warningThreshold) && $rawValue > $warningThreshold) {
-                $pieState = self::PERFDATA_WARNING;
-            }
-            if (isset($criticalThreshold) && $rawValue > $criticalThreshold) {
-                $pieState = self::PERFDATA_CRITICAL;
-            }
-        }
-
-        switch ($pieState) {
-            case self::PERFDATA_OK:
+        if ($this->criticalThreshold->contains($rawValue)) {
+            if ($this->warningThreshold->contains($rawValue)) {
                 $green = $usedValue;
-                break;
-
-            case self::PERFDATA_CRITICAL:
-                $red = $usedValue;
-                break;
-
-            case self::PERFDATA_WARNING:
+            } else {
                 $orange = $usedValue;
-                break;
+            }
+        } else {
+            $red = $usedValue;
         }
 
-        return array($green, $orange, $red, $gray);
+        return array($green, $orange, $red, ($this->getMaximumValue() - $minValue) - $usedValue);
     }
 
 
@@ -401,9 +425,6 @@ class Perfdata
         $pieChart = new InlinePie($data, $this);
         $pieChart->setColors(array('#44bb77', '#ffaa44', '#ff5566', '#ddccdd'));
 
-        if (Zend_Controller_Front::getInstance()->getRequest()->isXmlHttpRequest()) {
-            $pieChart->disableNoScript();
-        }
         return $pieChart;
     }
 
@@ -412,6 +433,19 @@ class Perfdata
      */
     protected function format($value)
     {
+        if ($value === null) {
+            return null;
+        }
+
+        if ($value instanceof ThresholdRange) {
+            if ($value->getMin()) {
+                return (string) $value;
+            }
+
+            $max = $value->getMax();
+            return $max === null ? '' : $this->format($max);
+        }
+
         if ($this->isPercentage()) {
             return (string)$value . '%';
         }
@@ -421,6 +455,9 @@ class Perfdata
         if ($this->isSeconds()) {
             return Format::seconds($value);
         }
+        if ($this->isTemperature()) {
+            return (string)$value . strtoupper($this->unit);
+        }
         return number_format($value, 2);
     }
 
@@ -443,15 +480,18 @@ class Perfdata
 
     public function toArray()
     {
-        $parts = array(
+        return array(
             'label' => $this->getLabel(),
             'value' => $this->format($this->getvalue()),
-            'min' => isset($this->minValue) && !$this->isPercentage() ? $this->format($this->minValue) : '',
-            'max' => isset($this->maxValue) && !$this->isPercentage() ? $this->format($this->maxValue) : '',
-            'warn' => isset($this->warningThreshold) ? $this->format(self::convert($this->warningThreshold, $this->unit)) : '',
-            'crit' => isset($this->criticalThreshold) ? $this->format(self::convert($this->criticalThreshold, $this->unit)) : ''
+            'min' => isset($this->minValue) && !$this->isPercentage()
+                ? $this->format($this->minValue)
+                : '',
+            'max' => isset($this->maxValue) && !$this->isPercentage()
+                ? $this->format($this->maxValue)
+                : '',
+            'warn' => $this->format($this->warningThreshold),
+            'crit' => $this->format($this->criticalThreshold)
         );
-        return $parts;
     }
 
     /**
@@ -467,13 +507,11 @@ class Perfdata
             return Service::STATE_UNKNOWN;
         }
 
-        if (! ($this->criticalThreshold === null
-            || $this->value < $this->criticalThreshold)) {
+        if (! $this->criticalThreshold->contains($this->value)) {
             return Service::STATE_CRITICAL;
         }
 
-        if (! ($this->warningThreshold === null
-            || $this->value < $this->warningThreshold)) {
+        if (! $this->warningThreshold->contains($this->value)) {
             return Service::STATE_WARNING;
         }
 
