@@ -1,6 +1,6 @@
-/*! Icinga Web 2 | (c) 2013-2015 Icinga Development Team | GPLv2+ */
+/*! Icinga Web 2 | (c) 2015 Icinga Development Team | GPLv2+ */
 
-// @TODO(el): https://dev.icinga.org/issues/10646
+// @TODO(el): https://dev.icinga.com/issues/10646
 (function(Icinga, $) {
 
     'use strict';
@@ -16,8 +16,13 @@
     ApplicationState.prototype = new Icinga.EventListener();
 
     ApplicationState.prototype.onRendered = function(e) {
-        var _this = e.data.self;
-        if (! $('#application-state').length) {
+        if (! $('#application-state').length
+            && ! $('#login').length
+            && ! $('#guest-error').length
+            && ! $('#setup').length
+        ) {
+            var _this = e.data.self;
+
             $('#layout').append(
                 '<div id="application-state" class="container" style="display: none" data-icinga-url="'
                 + _this.icinga.loader.baseUrl
