@@ -42,6 +42,11 @@
         var $modal = _this.$ghost.clone();
         var $urlTarget = _this.icinga.loader.getLinkTargetFor($a, false);
 
+        _this.modalOpener = event.currentTarget;
+
+        // Disable pointer events to block further function calls
+        _this.modalOpener.style.pointerEvents = 'none';
+
         // Add showCompact, we don't want controls in a modal
         url = _this.icinga.utils.addUrlFlag(url, 'showCompact');
 
@@ -91,7 +96,16 @@
         var $form = $(event.currentTarget).closest('form');
         var $modal = $form.closest('#modal');
 
-        var req = _this.icinga.loader.submitForm($form, $autoSubmittedBy);
+        var $button;
+        var $rememberedSubmittButton = $form.data('submitButton');
+        if (typeof $rememberedSubmittButton != 'undefined') {
+            if ($form.has($rememberedSubmittButton)) {
+                $button = $rememberedSubmittButton;
+            }
+            $form.removeData('submitButton');
+        }
+
+        var req = _this.icinga.loader.submitForm($form, $autoSubmittedBy, $button);
         req.addToHistory = false;
         req.$redirectTarget = $modal.data('redirectTarget');
         req.done(function (data, textStatus, req) {
@@ -100,6 +114,9 @@
             }
         });
 
+        // otherwise the form is submitted several times by clicking the "Submit" button several times
+        $form.find('input:not(:disabled)').prop('disabled', true);
+
         event.stopPropagation();
         event.preventDefault();
         return false;
@@ -187,6 +204,10 @@
      * @param $modal {jQuery} The modal element
      */
     Modal.prototype.hide = function($modal) {
+        // Remove pointerEvent none style to make the button clickable again
+        this.modalOpener.style.pointerEvents = '';
+        this.modalOpener = null;
+
         $modal.removeClass('active');
         // Using `setTimeout` here to let the transition finish
         setTimeout(function () {
