@@ -603,7 +603,7 @@
 
             if (typeof referrer !== 'undefined') {
                 rerenderLayout = referrer.getResponseHeader('X-Icinga-Rerender-Layout');
-                autoRefreshInterval = referrer.autoRefreshInterval;
+                autoRefreshInterval = referrer.getResponseHeader('X-Icinga-Refresh');
                 forceFocus = referrer.forceFocus;
                 origin = referrer.url;
             }
@@ -643,7 +643,9 @@
                     this.loadUrl(parts.shift(), $('#col2'));
                 } else {
                     if ($target.attr('id') === 'col2') { // TODO: multicol
-                        if ($('#col1').data('icingaUrl').split('?')[0] === url.split('?')[0]) {
+                        if (($target.data('icingaUrl') || '').split('?')[0] === url.split('?')[0]) {
+                            // Don't do anything in this case
+                        } else if ($('#col1').data('icingaUrl').split('?')[0] === url.split('?')[0]) {
                             icinga.ui.layout1col();
                             $target = $('#col1');
                             delete(this.requests['col2']);
@@ -714,7 +716,9 @@
             }
 
             if (req.getResponseHeader('X-Icinga-Announcements') === 'refresh') {
-                _this.loadUrl(_this.url('/layout/announcements'), $('#announcements'));
+                var announceReq = _this.loadUrl(_this.url('/layout/announcements'), $('#announcements'));
+                announceReq.addToHistory = false;
+                announceReq.scripted = true;
             }
 
             var rendered = false;
@@ -730,9 +734,7 @@
                 });
                 if (moduleName) {
                     // Lazy load module javascript (Applies only to module.js code)
-                    if (_this.icinga.hasModule(moduleName) && ! _this.icinga.isLoadedModule(moduleName)) {
-                        _this.icinga.loadModule(moduleName);
-                    }
+                    _this.icinga.ensureModule(moduleName);
 
                     req.$target.data('icingaModule', moduleName);
                     classes.push('icinga-module');
@@ -1021,13 +1023,10 @@
                 }
             }
 
-            req.$target.find('.container').each(function () {
-                // Lazy load module javascript (Applies only to module.js code)
-                var moduleName = $(this).data('icingaModule');
-                if (_this.icinga.hasModule(moduleName) && ! _this.icinga.isLoadedModule(moduleName)) {
-                    _this.icinga.loadModule(moduleName);
-                }
+            // Lazy load module javascript (Applies only to module.js code)
+            this.icinga.ensureSubModules(req.$target);
 
+            req.$target.find('.container').each(function () {
                 $(this).trigger('rendered', [req.autorefresh, req.scripted, req.autosubmit]);
             });
             req.$target.trigger('rendered', [req.autorefresh, req.scripted, req.autosubmit]);
@@ -1294,7 +1293,12 @@
             this.icinga.ui.assignUniqueContainerIds();
 
             if (! discard && navigationAnchor) {
-                setTimeout(this.icinga.ui.focusElement.bind(this.icinga.ui), 0, navigationAnchor, $container);
+                var $element = $container.find('#' + navigationAnchor);
+                if ($element.length) {
+                    // data-icinga-no-scroll-on-focus is NOT designed to avoid scrolling for non-XHR requests
+                    setTimeout(this.icinga.ui.focusElement.bind(this.icinga.ui), 0,
+                        $element, $container, ! $element.is('[data-icinga-no-scroll-on-focus]'));
+                }
             } else if (! activeElementPath) {
                 // Active element was not in this container
                 if (! autorefresh && ! autoSubmit && ! scripted) {
