@@ -131,24 +131,33 @@
                 result = parts.path,
                 newparams = parts.params;
 
+            // We overwrite existing params
             $.each(params, function (key, value) {
-              // We overwrite existing params
-              newparams[key] = value;
+                key = encodeURIComponent(key);
+                value = typeof value !== 'string' || !! value ? encodeURIComponent(value) : null;
+
+                var found = false;
+                for (var i = 0; i < newparams.length; i++) {
+                    if (newparams[i].key === key) {
+                        newparams[i].value = value;
+                        found = true;
+                        break;
+                    }
+                }
+
+                if (! found) {
+                    newparams.push({ key: key, value: value });
+                }
             });
 
-            if (Object.keys(newparams).length > 0) {
-              var queryString = '?';
-              $.each(newparams, function (key, value) {
-                  if (queryString !== '?') {
-                      queryString += '&';
-                  }
-                  queryString += encodeURIComponent(key) + '=' + encodeURIComponent(value);
-              });
-              result += queryString;
+            if (newparams.length) {
+                result += '?' + this.buildQuery(newparams);
             }
-            if (parts.hash.length > 0) {
+
+            if (parts.hash.length) {
                 result += '#' + parts.hash;
             }
+
             return result;
         },
 
@@ -158,46 +167,116 @@
                 result = parts.path,
                 newparams = parts.params;
 
-            $.each(params, function (idx, key) {
-                delete newparams[key];
+            $.each(params, function (_, key) {
+                key = encodeURIComponent(key);
+
+                for (var i = 0; i < newparams.length; i++) {
+                    if (newparams[i].key === key) {
+                        newparams.splice(i, 1);
+                        return;
+                    }
+                }
             });
 
-            if (Object.keys(newparams).length > 0) {
-              var queryString = '?';
-              $.each(newparams, function (key, value) {
-                  if (queryString !== '?') {
-                      queryString += '&';
-                  }
-                  queryString += encodeURIComponent(key) + '=' + encodeURIComponent(value);
-              });
-              result += queryString;
+            if (newparams.length) {
+                result += '?' + this.buildQuery(newparams);
             }
-            if (parts.hash.length > 0) {
+
+            if (parts.hash.length) {
                 result += '#' + parts.hash;
             }
+
             return result;
         },
 
+        /**
+         * Return a query string for the given params
+         *
+         * @param {Array} params
+         * @return {string}
+         */
+        buildQuery: function (params) {
+            var query = '';
+
+            for (var i = 0; i < params.length; i++) {
+                if (!! query) {
+                    query += '&';
+                }
+
+                query += params[i].key;
+                switch (params[i].value) {
+                    case true:
+                        break;
+                    case false:
+                        query += '=0';
+                        break;
+                    case null:
+                        query += '=';
+                        break;
+                    default:
+                        query += '=' + params[i].value;
+                }
+            }
+
+            return query;
+        },
+
         /**
          * Parse url params
          */
         parseParams: function (a) {
-            var params = {},
+            var params = [],
                 segment = a.search.replace(/^\?/,'').split('&'),
                 len = segment.length,
                 i = 0,
-                s;
+                key,
+                value,
+                equalPos;
 
             for (; i < len; i++) {
-                if (!segment[i]) {
+                if (! segment[i]) {
                     continue;
                 }
-                s = segment[i].split('=');
-                params[s[0]] = decodeURIComponent(s[1]);
+
+                equalPos = segment[i].indexOf('=');
+                if (equalPos !== -1) {
+                    key = segment[i].slice(0, equalPos);
+                    value = segment[i].slice(equalPos + 1);
+                } else {
+                    key = segment[i];
+                    value = true;
+                }
+
+                params.push({ key: key, value: value });
             }
+
             return params;
         },
 
+        /**
+         * Add the specified flag to the given URL
+         *
+         * @param {string} url
+         * @param {string} flag
+         *
+         * @returns {string}
+         */
+        addUrlFlag: function (url, flag) {
+            var pos = url.search(/#(?!!)/);
+
+            if (url.indexOf('?') !== -1) {
+                flag = '&' + flag;
+            } else {
+                flag = '?' + flag;
+            }
+
+            if (pos === -1) {
+                return url + flag;
+            }
+
+            return url.slice(0, pos) + flag + url.slice(pos);
+        },
+
         /**
          * Check whether two HTMLElements overlap
          *
@@ -272,49 +351,56 @@
         /**
          * Get the CSS selector to the given node
          *
-         * @param   {jQuery}    $node
+         * @param {HTMLElement} element
          *
          * @returns {string}
          */
-        getCSSPath: function($node) {
-            if (! $node.length) {
-                throw 'Requires a node';
+        getCSSPath: function(element) {
+            if (typeof element === 'undefined') {
+                throw 'Requires a element';
+            }
+
+            if (typeof element.jquery !== 'undefined') {
+                if (! element.length) {
+                    throw 'Requires a element';
+                }
+
+                element = element[0];
             }
 
             var path = [];
 
             while (true) {
-                var id = $node.attr('id');
+                var id = element.id;
 
-                if (typeof id !== 'undefined') {
+                // Ignore forms and form controls because id generation is unreliable :(
+                if (id && ! element.form && ! (element instanceof HTMLFormElement)) {
                     path.push('#' + id);
                     break;
                 }
 
-                var tagName = $node.prop('tagName').toLowerCase();
-                //var classes = $node.attr('class');
-                //
-                //if (classes) {
-                //    classes = classes.split(' ').join('.');
-                //}
+                var tagName = element.tagName;
+                var parent = element.parentElement;
 
-                var $parent = $node.parent();
-
-                if (! $parent.length) {
-                    path.push(tagName);
+                if (! parent) {
+                    path.push(tagName.toLowerCase());
                     break;
                 }
 
-                var $siblings = $parent.children(tagName);
+                if (parent.children.length) {
+                    var index = 0;
+                    do {
+                        if (element.tagName === tagName) {
+                            index++;
+                        }
+                    } while ((element = element.previousElementSibling));
 
-                if ($siblings.length > 1) {
-                    var index = $siblings.index($node) + 1;
-                    path.push(tagName + ':nth-of-type(' + index.toString() + ')');
+                    path.push(tagName.toLowerCase() + ':nth-of-type(' + index + ')');
                 } else {
-                    path.push(tagName);
+                    path.push(tagName.toLowerCase());
                 }
 
-                $node = $parent;
+                element = parent;
             }
 
             return path.reverse().join(' > ');
@@ -352,13 +438,40 @@
         },
 
         objectsEqual: function equals(obj1, obj2) {
-            return Object.keys(obj1)
-                .concat(Object.keys(obj2))
+            var obj1Keys = Object.keys(obj1);
+            var obj2Keys = Object.keys(obj2);
+            if (obj1Keys.length !== obj2Keys.length) {
+                return false;
+            }
+
+            return obj1Keys.concat(obj2Keys)
                 .every(function (key) {
                     return obj1[key] === obj2[key];
                 });
         },
 
+        arraysEqual: function (array1, array2) {
+            if (array1.length !== array2.length) {
+                return false;
+            }
+
+            var value1, value2;
+            for (var i = 0; i < array1.length; i++) {
+                value1 = array1[i];
+                value2 = array2[i];
+
+                if (typeof value1 === 'object') {
+                    if (typeof value2 !== 'object' || ! this.objectsEqual(value1, value2)) {
+                        return false;
+                    }
+                } else if (value1 !== value2) {
+                    return false;
+                }
+            }
+
+            return true;
+        },
+
         /**
          * Cleanup
          */
