@@ -26,7 +26,7 @@ class SuccessfulForm extends Form
 
 class FormTest extends BaseTestCase
 {
-    public function tearDown()
+    public function tearDown(): void
     {
         Mockery::close(); // Necessary as some tests are running isolated
     }
@@ -91,7 +91,9 @@ class FormTest extends BaseTestCase
     {
         $this->getRequestMock()->shouldReceive('getPathInfo')->andReturn('default/route');
         $this->getResponseMock()->shouldReceive('redirectAndExit')->atLeast()->once()
-            ->with(Mockery::on(function ($url) { return $url->getRelativeUrl() === 'default/route'; }));
+            ->with(Mockery::on(function ($url) {
+                return $url->getRelativeUrl() === 'default/route';
+            }));
 
         $form = new SuccessfulForm();
         $form->setTokenDisabled();
@@ -102,7 +104,9 @@ class FormTest extends BaseTestCase
     public function testWhetherAnExplicitlySetRedirectUrlIsUsedForRedirection()
     {
         $this->getResponseMock()->shouldReceive('redirectAndExit')->atLeast()->once()
-            ->with(Mockery::on(function ($url) { return $url->getRelativeUrl() === 'special/route'; }));
+            ->with(Mockery::on(function ($url) {
+                return $url->getRelativeUrl() === 'special/route';
+            }));
 
         $form = new SuccessfulForm();
         $form->setTokenDisabled();
@@ -247,11 +251,10 @@ class FormTest extends BaseTestCase
         );
     }
 
-    /**
-     * @expectedException \Icinga\Exception\ProgrammingError
-     */
     public function testWhetherTheOnSuccessOptionMustBeCallable()
     {
+        $this->expectException(\Icinga\Exception\ProgrammingError::class);
+
         new Form(array('onSuccess' => '_invalid_'));
     }
 
@@ -264,7 +267,10 @@ class FormTest extends BaseTestCase
     {
         $request = new Request();
         $form = new Form(array(
-            'onSuccess' => function ($form) { $form->getRequest()->setParam('test', 'tset'); return false; }
+            'onSuccess' => function ($form) {
+                $form->getRequest()->setParam('test', 'tset');
+                return false;
+            }
         ));
         $form->setTokenDisabled();
         $form->setUidDisabled();
